﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Workshops.Model.Validation
{
    public class AttendeeValidationRule : IValidationRule
    {
        public ValidationResult Validate<T>(T businessObject) where T : IBusinessObject
        {
            var attendee = businessObject as Attendee;

            if (attendee == null)
            {
                throw new ArgumentException("Wrong business object type given for validation or business object is null.", "businessObject");
            }

            if (string.IsNullOrWhiteSpace(attendee.FirstName))
            {
                return new ValidationResult(ValidationResultType.Error, "Please enter a first name.");
            }

            if (string.IsNullOrWhiteSpace(attendee.LastName))
            {
                return new ValidationResult(ValidationResultType.Error, "Please enter a last name.");
            }

            if (attendee.FirstName.Length > 30)
            {
                return new ValidationResult(ValidationResultType.Error, "The maximum length of first names is 30 characters.");
            }

            if (attendee.LastName.Length > 30)
            {
                return new ValidationResult(ValidationResultType.Error, "The maximum length of last names is 30 characters.");
            }

            return ValidationResult.ValidResult;
        }

        public Type TargetType
        {
            get
            {
                return typeof(Attendee);
            }
        }
    }
}
