﻿using System;

namespace Workshops.Model.Validation
{
    public class WorkshopValidationRule : IValidationRule
    {
        public ValidationResult Validate<T>(T businessObject) where T : IBusinessObject
        {
            var workshop = businessObject as Workshop;

            if (workshop == null)
            {
                throw new ArgumentException("Wrong business object type given for validation or business object is null.", "businessObject");
            }

            if (string.IsNullOrWhiteSpace(workshop.Title))
            {
                return new ValidationResult(ValidationResultType.Error, "A workshop must have a title.");
            }

            if (workshop.EventDate < DateTime.Now)
            {
                return new ValidationResult(ValidationResultType.Error, "A workshop date must be in the future.");
            }

            return ValidationResult.ValidResult;
        }

        public Type TargetType
        {
            get
            {
                return typeof(Workshop);
            }
        }
    }
}