﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;
using Microsoft.Practices.Unity;
using Workshops.Model;
using Workshops.Model.UnitsOfWork;
using Workshops.ViewModels.Navigation;

namespace Workshops.ViewModels
{
    public class DisplayWorkshopsViewModel : ViewModelBase, IViewModel
    {
        private Workshop _selectedWorkshop;

        [Dependency]
        public INavigationService NavigationService
        {
            get;
            set;
        }

        [Dependency]
        public IUnitOfWorkFactory UnitOfWorkFactory
        {
            get;
            set;
        }

        public ObservableCollection<Workshop> AllWorkshops
        {
            get;
            private set;
        }

        public Workshop SelectedWorkshop
        {
            get
            {
                return _selectedWorkshop;
            }
            set
            {
                _selectedWorkshop = value;
                RaisePropertyChanged("SelectedWorkshop");
            }
        }

        public ICommand EditSelectedWorkshopCommand
        {
            get;
            private set;
        }

        public ICommand CreateNewWorkshopCommand
        {
            get;
            private set;
        }

        public DisplayWorkshopsViewModel()
        {
            AllWorkshops = new ObservableCollection<Workshop>();
            EditSelectedWorkshopCommand = new RelayCommand(EditSelectedWorkshop);
            CreateNewWorkshopCommand = new RelayCommand(CreateNewWorkshop);
        }

        public void Initialize()
        {
            using (var unitOfWork = UnitOfWorkFactory.CreateUnitOfWork())
            {
                var workshops = unitOfWork.WorkshopsRepository.GetAllWorkshops();
                AllWorkshops = new ObservableCollection<Workshop>(workshops);
                
                if (AllWorkshops.Count > 0)
                {
                    SelectedWorkshop = AllWorkshops[0];
                }
            }
        }

        private void EditSelectedWorkshop()
        {
            if (SelectedWorkshop == null)
            {
                MessageBox.Show("Please select a workshop first.");
                return;
            }
            
            // navigate
            NavigationService.Navigate<EditWorkshopViewModel>(SelectedWorkshop);
        }
        
        private void CreateNewWorkshop()
        {
            // create workshop
            var workshop = new Workshop();
            workshop.EventDate = DateTime.Now;
            
            // navigate
            NavigationService.Navigate<EditWorkshopViewModel>(workshop);
        }
    }
}
