﻿using System;
using System.Collections.Generic;
using GalaSoft.MvvmLight;
using Microsoft.Practices.Unity;

namespace Workshops.ViewModels.Factory
{
    public class ViewModelFactory : IViewModelFactory
    {
        private readonly IUnityContainer _container;

        public ViewModelFactory(IUnityContainer container)
        {
            _container = container;
        }

        public T Create<T>(params object[] arguments) where T : IViewModel
        {
            T viewModel;

            // create view model
            if (arguments.Length == 0)
            {
                viewModel = Activator.CreateInstance<T>();
            }
            else
            {
                viewModel = (T)Activator.CreateInstance(typeof(T), arguments);
            }
            
            // resolve dependencies
            _container.BuildUp(viewModel);

            // initialize
            viewModel.Initialize();
            
            return viewModel;
        }
    }
}