﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;
using Workshops.Model;

namespace Workshops.ViewModels
{
    public class DisplayWorkshopsViewModel : ViewModelBase
    {
        private Workshop _selectedWorkshop;

        public ObservableCollection<Workshop> AllWorkshops
        {
            get;
            private set;
        }

        public Workshop SelectedWorkshop
        {
            get
            {
                return _selectedWorkshop;
            }
            set
            {
                _selectedWorkshop = value;
                RaisePropertyChanged("SelectedWorkshop");
            }
        }

        public ICommand EditSelectedWorkshopCommand
        {
            get;
            private set;
        }

        public ICommand CreateNewWorkshopCommand
        {
            get;
            private set;
        }

        public DisplayWorkshopsViewModel()
        {
            AllWorkshops = new ObservableCollection<Workshop>();
            EditSelectedWorkshopCommand = new RelayCommand(EditSelectedWorkshop);
            CreateNewWorkshopCommand = new RelayCommand(CreateNewWorkshop);

            LoadWorkshops();
        }

        private void LoadWorkshops()
        {
            using (var context = new WorkshopsDatabaseContext())
            {
                var workshops = context.Workshops
                                       .Include("Attendees")
                                       .OrderByDescending(w => w.EventDate)
                                       .ToList();

                workshops.ForEach(w => AllWorkshops.Add(w));

                if (workshops.Count > 0)
                {
                    SelectedWorkshop = workshops[0];
                }
            }
        }

        private void EditSelectedWorkshop()
        {
            if (SelectedWorkshop == null)
            {
                MessageBox.Show("Please select a workshop first.");
                return;
            }
            
            // create view model
            var editWorkshopVM = new EditWorkshopViewModel(SelectedWorkshop);

            // navigate!
            var app = Application.Current as App;
            if (app != null)
            {
                app.ShellViewModel.CurrentPage = editWorkshopVM;
            }
        }
        
        private void CreateNewWorkshop()
        {
            // create workshop
            var workshop = new Workshop();
            workshop.EventDate = DateTime.Now;

            // create view model
            var editWorkshopVM = new EditWorkshopViewModel(workshop);

            // navigate!
            var app = Application.Current as App;
            if (app != null)
            {
                app.ShellViewModel.CurrentPage = editWorkshopVM;
            }
        }
    }
}
